Parallel chunking orchestrator.
Wraps another chunker and processes chunks in parallel using rayon for improved performance on large texts.
Structs
- Parallel
Chunker - Parallel chunking orchestrator.
Parallel chunking orchestrator.
Wraps another chunker and processes chunks in parallel using rayon for improved performance on large texts.