pub fn format_error(error: &Error, format: OutputFormat) -> StringExpand description
Formats an error for output.
When format is JSON, returns a structured error object. When format is Text, returns the error message string.
pub fn format_error(error: &Error, format: OutputFormat) -> StringFormats an error for output.
When format is JSON, returns a structured error object. When format is Text, returns the error message string.