Module io

Module io 

I/O utilities for RLM-RS.

Provides file reading with memory mapping support for efficient handling of large files, along with Unicode utilities.

Re-exports

pub use reader::FileReader;
pub use reader::read_file;
pub use reader::read_file_mmap;
pub use reader::write_chunks;
pub use reader::write_file;
pub use unicode::current_timestamp;
pub use unicode::find_char_boundary;
pub use unicode::validate_utf8;

Modules

reader
File reading utilities with memory mapping support.
unicode
Unicode utilities for text processing.