pub struct FileReader { /* private fields */ }Expand description
File reader with support for memory mapping.
Automatically chooses the best reading strategy based on file size:
- Small files (< 1MB): Read directly into memory
- Large files (>= 1MB): Use memory mapping
Examples
use rlm_rs::io::FileReader;
let reader = FileReader::open("large_file.txt").unwrap();
let content = reader.read_to_string().unwrap();Implementations
Sourceimpl FileReader
impl FileReader
Sourcepub fn read_to_string(&self) -> Result<String>
pub fn read_to_string(&self) -> Result<String>
Reads the file content as a string.
Uses memory mapping for large files.
Errors
Returns an error if reading fails or content is not valid UTF-8.
Sourcepub fn read_to_bytes(&self) -> Result<Vec<u8>>
pub fn read_to_bytes(&self) -> Result<Vec<u8>>