Storage trait definition.
Defines the interface for persistent storage backends, enabling pluggable storage implementations.
Structs
- Storage
Stats - Storage statistics.
Traits
- Storage
- Trait for persistent storage backends.
Storage trait definition.
Defines the interface for persistent storage backends, enabling pluggable storage implementations.